/*

The Life of a Geek
Copyright (C) 2003 Daniel Quintiliani

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

You can e-mail Daniel Quintiliani at coredump@coredumpcentral.org

func.h: Commands and misc functions

6/14/03: Daniel Quintiliani <coredump@coredumpcentral.org>: Fixed support for
older compilers/C libraries.
6/13/03: Daniel Quintiliani <coredump@coredumpcentral.org>: Updated 
readfromfilevars(),
changed floattostring() to currencytostring(), added floattocurrency().
5/21/03: Daniel Quintiliani <coredump@coredumpcentral.org>: CmdWasteTime()
updated.
5/20/03: Daniel Quintiliani <coredump@coredumpcentral.org>: Added 
readfromfilevars(), inttostring(), removed FuncGenGameName() and FuncGenEmu()
4/24/03: Daniel Quintiliani <coredump@coredumpcentral.org>: Added readfromfile()
4/7/03: Daniel Quintiliani <coredump@coredumpcentral.org>: added
gpl_check_and_strlwr()

*/

#ifndef _FUNC_H
#define _FUNC_H

#include "version.h"
#include <string>
#include "geek.h"
#include "comp.h"
#include "eltime.h"

using namespace std;

void CmdWasteTime(Geek &geek, Computer &comp, ElTime &elt); // Waste time
void CmdSpeedClass(Geek &geek, Computer &comp, ElTime &elt);
				// Take a speed class
void CmdWork(Geek &geek, Computer &comp, ElTime &elt); // Find a job.
void CmdBuyEnergyDrink(Geek &geek, ElTime &elt, int n); // Buy an energy drink.
void CmdDrinkEnergyDrink(Geek &geek, ElTime &elt); // Drink an energy drink.
void CmdHack(Geek &geek, Computer &comp, ElTime &elt); // Hack another geek.
void CmdAntiVirus(Geek &geek, Computer &comp, ElTime &elt);
					// Run anti-virus service.
void CmdSleep(Geek &geek, Computer &comp, ElTime &elt); // Sleep.

void FuncGenAttack(Computer &comp, int Percent); // Percent risk of attack
char* gpl_check_and_strlwr(string& s); // Does gpl_check() and strlwr().
				      // Returns C string.
const char* readfromfile(const char* filename, const char* id, int newline);
			 // Reads and returns lines from file filename beginning
			//  with identifier id. If newline is zero, '\n' is
			// added at the end of each line.
const char* readfromfilevars(const char* filename, const char* id, int newline,
			Geek geek, Computer comp, ElTime elt, int intvar,
			float floatvar, const char* cstrvar,
			const char* YInfected, const char* NInfected);
			// Same as above but used when variables are involved.
const char* inttostring(int n); // Converts n to c string using ostringstream.
const char* currencytostring(float f); // Ditto, but with a float, formatted
					// like currency (two decimal places,
					// rounded to hundredths place)
float floattocurrency(float f); // Returns f rounded to hundredths place

#if !defined _ISOC9X_SOURCE || !defined _ISOC99_SOURCE
float truncf(float x); // For purposes of this program, will be same as floorf.
float roundf(float x);
#endif

#endif
